@@ -1,11 +1,11 @@
 #include "commonmarker.h"
-#include "cmark.h"
+#include "cmark-gfm.h"
 #include "houdini.h"
 #include "node.h"
 #include "registry.h"
 #include "parser.h"
 #include "syntax_extension.h"
-#include "core-extensions.h"
+#include "cmark-gfm-core-extensions.h"
 
 static VALUE rb_mNodeError;
 static VALUE rb_mNode;
@@ -1034,6 +1034,20 @@ static VALUE rb_node_set_fence_info(VALUE self, VALUE info) {
   return Qnil;
 }
 
+static VALUE rb_node_get_tasklist_state(VALUE self) {
+  const char *tasklist_state;
+  cmark_node *node;
+  Data_Get_Struct(self, cmark_node, node);
+
+  tasklist_state = cmark_gfm_extensions_get_tasklist_state(node);
+
+  if (tasklist_state == NULL) {
+    rb_raise(rb_mNodeError, "could not get tasklist_state");
+  }
+
+  return rb_str_new2(tasklist_state);
+}
+
 static VALUE rb_node_get_table_alignments(VALUE self) {
   uint16_t column_count, i;
   uint8_t *alignments;
@@ -1041,8 +1055,8 @@ static VALUE rb_node_get_table_alignments(VALUE self) {
   VALUE ary;
   Data_Get_Struct(self, cmark_node, node);
 
-  column_count = cmarkextensions_get_table_columns(node);
-  alignments = cmarkextensions_get_table_alignments(node);
+  column_count = cmark_gfm_extensions_get_table_columns(node);
+  alignments = cmark_gfm_extensions_get_table_alignments(node);
 
   if (!column_count || !alignments) {
     rb_raise(rb_mNodeError, "could not get column_count or alignments");
@@ -1189,9 +1203,10 @@ __attribute__((visibility("default"))) void Init_commonmarker() {
   rb_define_method(rb_mNode, "fence_info", rb_node_get_fence_info, 0);
   rb_define_method(rb_mNode, "fence_info=", rb_node_set_fence_info, 1);
   rb_define_method(rb_mNode, "table_alignments", rb_node_get_table_alignments, 0);
+  rb_define_method(rb_mNode, "tasklist_state", rb_node_get_tasklist_state, 0);
 
   rb_define_method(rb_mNode, "html_escape_href", rb_html_escape_href, 1);
   rb_define_method(rb_mNode, "html_escape_html", rb_html_escape_html, 1);
 
-  core_extensions_ensure_registered();
+  cmark_gfm_core_extensions_ensure_registered();
 }
