@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 require 'ruby-enum'
 module CommonMarker
   # For Ruby::Enum, these must be classes, not modules
@@ -11,6 +13,7 @@ module CommonMarker
       define :LIBERAL_HTML_TAG, (1 << 12)
       define :FOOTNOTES, (1 << 13)
       define :STRIKETHROUGH_DOUBLE_TILDE, (1 << 14)
+      define :UNSAFE, (1 << 17)
     end
 
     class Render
@@ -19,10 +22,11 @@ module CommonMarker
       define :DEFAULT, 0
       define :SOURCEPOS, (1 << 1)
       define :HARDBREAKS, (1 << 2)
-      define :SAFE, (1 << 3)
       define :NOBREAKS, (1 << 4)
       define :GITHUB_PRE_LANG, (1 << 11)
       define :TABLE_PREFER_STYLE_ATTRIBUTES, (1 << 15)
+      define :FULL_INFO_STRING, (1 << 16)
+      define :UNSAFE, (1 << 17)
     end
 
     def self.process_options(option, type)
@@ -35,12 +39,12 @@ module CommonMarker
         # neckbearding around. the map will both check the opts and then bitwise-OR it
         option.map { |o| check_option(o, type); type.to_h[o] }.inject(0, :|)
       else
-        raise TypeError, 'option type must be a valid symbol or array of symbols'
+        raise TypeError, "option type must be a valid symbol or array of symbols within the #{type} context"
       end
     end
 
     def self.check_option(option, type)
-      unless type.keys.include?(option)
+      unless type.key?(option)
         raise TypeError, "option ':#{option}' does not exist for #{type}"
       end
     end
