@@ -1,10 +1,12 @@
 # coding: utf-8
+# frozen_string_literal: true
+
 require 'test_helper'
 
 class TestEncoding < Minitest::Test
   # see http://git.io/vq4FR
   def test_encoding
-    contents = File.read(File.join(FIXTURES_DIR, 'curly.md'), encoding: 'utf-8')
+    contents = fixtures_file('curly.md')
     doc = CommonMarker.render_doc(contents, :SMART)
     render = doc.to_html
     assert_equal render.rstrip, '<p>This curly quote “makes commonmarker throw an exception”.</p>'
